@@ -10,7 +10,7 @@ class APIError(CorvaException):
     pass
 
 
-class AssetNotFound(CorvaException):
+class NotFound(CorvaException):
     pass
 
 
